@@ -26,7 +26,7 @@ def __get_current_file_id():
 
 def get_file_id(path):
     try:
-        return xattr.getxattr(path, 'user.drive.id')
+        return xattr.getxattr(path, 'user.drive.id').decode()
     except (OSError, FileNotFoundError):
         return None
 
@@ -58,7 +58,8 @@ def get_colab_current_file_path() -> Optional[Path]:
             ),
             None
         )
-        return Path(file_path)
+        if file_path:
+            return Path(file_path)
 
     return None
 
